@@ -125,8 +125,22 @@ sub server {
     $logger->info("RPC service started at: ". $daemon->url);
 
     my @stack;
-    while (sleep 1) {
-        next if threads->list(threads::running) > 10;
+    while (1) {
+        # Limit to 10 the max number of running thread
+        LIMIT: while (@stack > 10) {
+            foreach (0..@stack-1) {
+                my $thr = $stack[$_];
+                # is_joinable is not avalaible on perl 5.8
+                if (eval {$thr->is_joinable();1;}) {
+                    $thr->join();
+                    splice(@stack, $_, 1);
+                    last LIMIT;
+                }
+            }
+            # This is the plan B
+            my $thr = shift(@stack);
+            $thr->join();
+        }
         my $c = $daemon->accept;
         my $thr = threads->create(\&handler, $self, $c);
         push @stack, $thr;
